==> haskell-nettle-0.2.0-1-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-nettle.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: nettle
version: 0.2.0
id: nettle-0.2.0-CREosAoHSCSFu9JvG7Ng4l
key: nettle-0.2.0-CREosAoHSCSFu9JvG7Ng4l
license: MIT
copyright: Stefan Bühler <stbuehler@web.de>
maintainer: Stefan Bühler <stbuehler@web.de>
homepage: https://github.com/stbuehler/haskell-nettle
synopsis: safe nettle binding
description:
    safe binding for the nettle (<http://www.lysator.liu.se/~nisse/nettle/nettle.html>) library.
    Tested with 3.1.1, might work with 3.0, does NOT WORK with 2.x.
category: Cryptography
author: Stefan Bühler <stbuehler@web.de>
exposed: True
exposed-modules:
    Crypto.Nettle.ChaChaPoly1305 Crypto.Nettle.Ciphers
    Crypto.Nettle.CCM Crypto.Nettle.Hash Crypto.Nettle.KeyedHash
    Crypto.Nettle.HMAC Crypto.Nettle.UMAC
hidden-modules: Crypto.Nettle.Ciphers.Internal
                Crypto.Nettle.Ciphers.ForeignImports
                Crypto.Nettle.Hash.ForeignImports Crypto.Nettle.Hash.Types
                Nettle.Utils
abi: a078f2fe478e3786ba168124d0a2fa60
trusted: False
import-dirs: /usr/lib/ghc-8.0.1/site-local/nettle-0.2.0
library-dirs: /usr/lib/ghc-8.0.1/site-local/nettle-0.2.0
data-dir: /usr/share/arm-linux-ghc-8.0.1/nettle-0.2.0
hs-libraries: HSnettle-0.2.0-CREosAoHSCSFu9JvG7Ng4l
extra-libraries:
    nettle
depends:
    base-4.9.0.0 byteable-0.1.1-15aIBCArSOBEnGxArzrDTM
    bytestring-0.10.8.1
    crypto-cipher-types-0.0.9-D0DdUwYNchw8RAl6A55EMq
    securemem-0.1.9-HztgpoIdC1f7G9KSDGKB9f
    tagged-0.8.5-I7Gu0uzBLkQJCVUvdvwKKq
haddock-interfaces: /usr/share/doc/haskell-nettle/html/nettle.haddock
haddock-html: /usr/share/doc/haskell-nettle/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-nettle-0.2.0-3-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-nettle.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: nettle
version: 0.2.0
id: nettle-0.2.0-3S23PH1Z9tsGAaCimQZTft
key: nettle-0.2.0-3S23PH1Z9tsGAaCimQZTft
license: MIT
copyright: Stefan Bühler <stbuehler@web.de>
maintainer: Stefan Bühler <stbuehler@web.de>
homepage: https://github.com/stbuehler/haskell-nettle
synopsis: safe nettle binding
description:
    safe binding for the nettle (<http://www.lysator.liu.se/~nisse/nettle/nettle.html>) library.
    Tested with 3.1.1, might work with 3.0, does NOT WORK with 2.x.
category: Cryptography
author: Stefan Bühler <stbuehler@web.de>
exposed: True
exposed-modules:
    Crypto.Nettle.ChaChaPoly1305 Crypto.Nettle.Ciphers
    Crypto.Nettle.CCM Crypto.Nettle.Hash Crypto.Nettle.KeyedHash
    Crypto.Nettle.HMAC Crypto.Nettle.UMAC
hidden-modules: Crypto.Nettle.Ciphers.Internal
                Crypto.Nettle.Ciphers.ForeignImports
                Crypto.Nettle.Hash.ForeignImports Crypto.Nettle.Hash.Types
                Nettle.Utils
abi: 4d0b568cd6f949ce289ccbd63e269e90
trusted: False
import-dirs: /usr/lib/ghc-8.0.1/site-local/nettle-0.2.0
library-dirs: /usr/lib/ghc-8.0.1/site-local/nettle-0.2.0
data-dir: /usr/share/arm-linux-ghc-8.0.1/nettle-0.2.0
hs-libraries: HSnettle-0.2.0-3S23PH1Z9tsGAaCimQZTft
extra-libraries:
    nettle
depends:
    base-4.9.0.0 byteable-0.1.1-15aIBCArSOBEnGxArzrDTM
    bytestring-0.10.8.1
    crypto-cipher-types-0.0.9-2P00NWAGGxtEOd0vR6cD69
    securemem-0.1.9-2y2iWaYcJrVGo5N3TsU2wJ
    tagged-0.8.5-I7Gu0uzBLkQJCVUvdvwKKq
haddock-interfaces: /usr/share/doc/haskell-nettle/html/nettle.haddock
haddock-html: /usr/share/doc/haskell-nettle/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
